@@ -292,8 +292,8 @@ def manufacture_entity_criteria(entity, include_only=None, exclude=None):
     existing = dict(
         (attr.key, attr.loaded_value)
         for attr in state.attrs
-        if attr.loaded_value is not orm.attributes.NO_VALUE
-        and attr.key not in exclude
+        if attr.loaded_value is not orm.attributes.NO_VALUE and
+        attr.key not in exclude
     )
     if include_only:
         existing = dict(
@@ -484,11 +484,10 @@ def _update_stmt_from_query(mapper, query, values):
             mapper.column_attrs[key], value
         ) for key, value in values.items()
     )
-    query = query.enable_eagerloads(False)
-    context = query._compile_context()
-    primary_table = context.statement.froms[0]
+    primary_table = inspect(query.column_descriptions[0]['entity']).local_table
+    where_criteria = query.whereclause
     update_stmt = sql.update(primary_table,
-                             context.whereclause,
+                             where_criteria,
                              upd_values)
     return update_stmt
 
